// -*- C++ -*-
/*!
 * @file  Bumblebee2Camera.h * @brief Bumblebee2 Camera component * @date  $Date$ 
 *
 * $Id$ 
 */
#ifndef BUMBLEBEE2CAMERA_H
#define BUMBLEBEE2CAMERA_H

#include <rtm/idl/BasicDataTypeSkel.h>
#include <rtm/Manager.h>
#include <rtm/DataFlowComponentBase.h>
#include <rtm/CorbaPort.h>
#include <rtm/DataInPort.h>
#include <rtm/DataOutPort.h>

// Service implementation headers
// <rtc-template block="service_impl_h">
#include "CameraInfoSVC_impl.h"

// </rtc-template>

// Service Consumer stub headers
// <rtc-template block="consumer_stub_h">

// </rtc-template>
#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include <assert.h>

#include <cv.h>
#include <cxcore.h>
#include <highgui.h>
#include <iostream>
using namespace std;

#include "control.h"

using namespace RTC;

class Bumblebee2Camera  : public RTC::DataFlowComponentBase
{
 public:
  Bumblebee2Camera(RTC::Manager* manager);
  ~Bumblebee2Camera();

  // The initialize action (on CREATED->ALIVE transition)
  // formaer rtc_init_entry() 
 virtual RTC::ReturnCode_t onInitialize();

  // The finalize action (on ALIVE->END transition)
  // formaer rtc_exiting_entry()
 virtual RTC::ReturnCode_t onFinalize();

  // The startup action when ExecutionContext startup
  // former rtc_starting_entry()
  // virtual RTC::ReturnCode_t onStartup(RTC::UniqueId ec_id);

  // The shutdown action when ExecutionContext stop
  // former rtc_stopping_entry()
  // virtual RTC::ReturnCode_t onShutdown(RTC::UniqueId ec_id);

  // The activated action (Active state entry action)
  // former rtc_active_entry()
 virtual RTC::ReturnCode_t onActivated(RTC::UniqueId ec_id);

  // The deactivated action (Active state exit action)
  // former rtc_active_exit()
 virtual RTC::ReturnCode_t onDeactivated(RTC::UniqueId ec_id);

  // The execution action that is invoked periodically
  // former rtc_active_do()
 virtual RTC::ReturnCode_t onExecute(RTC::UniqueId ec_id);

  // The aborting action when main logic error occurred.
  // former rtc_aborting_entry()
  // virtual RTC::ReturnCode_t onAborting(RTC::UniqueId ec_id);

  // The error action in ERROR state
  // former rtc_error_do()
  // virtual RTC::ReturnCode_t onError(RTC::UniqueId ec_id);

  // The reset action that is invoked resetting
  // This is same but different the former rtc_init_entry()
  // virtual RTC::ReturnCode_t onReset(RTC::UniqueId ec_id);
  
  // The state update action that is invoked after onExecute() action
  // no corresponding operation exists in OpenRTm-aist-0.2.0
  // virtual RTC::ReturnCode_t onStateUpdate(RTC::UniqueId ec_id);

  // The action that is invoked when execution context's rate is changed
  // no corresponding operation exists in OpenRTm-aist-0.2.0
  // virtual RTC::ReturnCode_t onRateChanged(RTC::UniqueId ec_id);


 protected:
  // Configuration variable declaration
  // <rtc-template block="config_declare">
  int m_WIDTH;
  int m_HEIGHT;
  
  // </rtc-template>

  // DataInPort declaration
  // <rtc-template block="inport_declare">

  // </rtc-template>

  // DataOutPort declaration
  // <rtc-template block="outport_declare">
  TimedOctetSeq m_Color;
  OutPort<TimedOctetSeq> m_ColorOut;
  TimedOctetSeq m_ColorRight;
  OutPort<TimedOctetSeq> m_ColorRightOut;
  TimedOctetSeq m_Disparity;
  OutPort<TimedOctetSeq> m_DisparityOut;
  TimedXYZLongSeq m_XYZLong;
  OutPort<TimedXYZLongSeq> m_XYZLongOut;
  TimedXYZDoubleSeq m_XYZDouble;
  OutPort<TimedXYZDoubleSeq> m_XYZDoubleOut;

  // </rtc-template>

  // CORBA Port declaration
  // <rtc-template block="corbaport_declare">
  RTC::CorbaPort m_CapPORTPort;

  // </rtc-template>

  // Service declaration
  // <rtc-template block="service_declare">
  CameraInfoSVC_impl m_CameraInfo;

  // </rtc-template>

  // Consumer declaration
  // <rtc-template block="consumer_declare">

  // </rtc-template>

 private:

	Bumblebee2Control bumblebee;
	int CapHeight;
	int CapWidth;	
	int CapBytesPerPixel;
	int bColor;


	int Height;
	int Width;
	int Channels;

	IplImage *left, *leftmono, *leftRGB, *leftResize, *leftmonoResize;
	IplImage *right, *rightmono, *rightRGB, *rightResize, *rightmonoResize, *rightRect;
	IplImage *disp, *dispResize;
	//IplImage *center ,*centermono, *centerRGB;
	IplImage *rect;

	double *xxx,*yyy,*zzz;
	short int *disparity;
	double now_t, old_t, dt;
	long double sumtime;
	double t;
	int frame;

};


extern "C"
{
  DLL_EXPORT void Bumblebee2CameraInit(RTC::Manager* manager);
};

#endif // BUMBLEBEE2CAMERA_H

